@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
 $EXTRACTRC `find . -name \*.ui -o -name \*.rc -o -name \*.kcfg` >> rc.cpp
-$XGETTEXT `find . -name \*.cpp` -o $podir/dolphin.pot
+$XGETTEXT `find . -name \*.cpp \! -path '*/servicemenuinstaller/*'` -o $podir/dolphin.pot
 rm -f rc.cpp
