@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Peter Penz <peter.penz19@gmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2011 Peter Penz <peter.penz19@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "kfileitemlistwidget.h"
 #include "kfileitemmodel.h"
@@ -69,17 +56,13 @@ QString KFileItemListWidgetInformant::roleText(const QByteArray& role,
             // The item represents a directory.
             if (!roleValue.isNull()) {
                 const int count = values.value("count").toInt();
-                if (count < 0) {
-                    text = i18nc("@item:intable", "Unknown");
-                } else {
+                if (count > 0) {
                     if (DetailsModeSettings::directorySizeCount()) {
                         //  Show the number of sub directories instead of the file size of the directory.
                         text = i18ncp("@item:intable", "%1 item", "%1 items", count);
                     } else {
                         // if we have directory size available
-                        if (roleValue == -1) {
-                            text = i18nc("@item:intable", "Unknown");
-                        } else {
+                        if (roleValue != -1) {
                             const KIO::filesize_t size = roleValue.value<KIO::filesize_t>();
                             text = KFormat().formatByteSize(size);
                         }
