@@ -1,24 +1,11 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Peter Penz <peter.penz19@gmail.com>             *
- *   Copyright (C) 2011 by Frank Reininghaus <frank78ac@googlemail.com>    *
- *                                                                         *
- *   Based on the Itemviews NG project from Trolltech Labs                 *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2011 Peter Penz <peter.penz19@gmail.com>
+ * SPDX-FileCopyrightText: 2011 Frank Reininghaus <frank78ac@googlemail.com>
+ *
+ * Based on the Itemviews NG project from Trolltech Labs
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "kitemlistselectionmanager.h"
 
@@ -48,12 +35,12 @@ void KItemListSelectionManager::setCurrentItem(int current)
     }
 
     if (m_currentItem != previous) {
-        emit currentChanged(m_currentItem, previous);
+        Q_EMIT currentChanged(m_currentItem, previous);
 
         if (m_isAnchoredSelectionActive) {
             const KItemSet selection = selectedItems();
             if (selection != previousSelection) {
-                emit selectionChanged(selection, previousSelection);
+                Q_EMIT selectionChanged(selection, previousSelection);
             }
         }
     }
@@ -69,7 +56,7 @@ void KItemListSelectionManager::setSelectedItems(const KItemSet& items)
     if (m_selectedItems != items) {
         const KItemSet previous = m_selectedItems;
         m_selectedItems = items;
-        emit selectionChanged(m_selectedItems, previous);
+        Q_EMIT selectionChanged(m_selectedItems, previous);
     }
 }
 
@@ -158,7 +145,7 @@ void KItemListSelectionManager::setSelected(int index, int count, SelectionMode
 
     const KItemSet selection = selectedItems();
     if (selection != previous) {
-        emit selectionChanged(selection, previous);
+        Q_EMIT selectionChanged(selection, previous);
     }
 }
 
@@ -168,7 +155,7 @@ void KItemListSelectionManager::clearSelection()
     if (!previous.isEmpty()) {
         m_selectedItems.clear();
         m_isAnchoredSelectionActive = false;
-        emit selectionChanged(KItemSet(), previous);
+        Q_EMIT selectionChanged(KItemSet(), previous);
     }
 }
 
@@ -235,7 +222,7 @@ void KItemListSelectionManager::itemsInserted(const KItemRangeList& itemRanges)
     } else {
         const int previousCurrent = m_currentItem;
         int inc = 0;
-        foreach (const KItemRange& itemRange, itemRanges) {
+        for (const KItemRange& itemRange : itemRanges) {
             if (m_currentItem < itemRange.index) {
                 break;
             }
@@ -247,7 +234,7 @@ void KItemListSelectionManager::itemsInserted(const KItemRangeList& itemRanges)
         if (m_currentItem >= m_model->count()) {
             m_currentItem = -1;
         }
-        emit currentChanged(m_currentItem, previousCurrent);
+        Q_EMIT currentChanged(m_currentItem, previousCurrent);
     }
 
     // Update the anchor item
@@ -255,7 +242,7 @@ void KItemListSelectionManager::itemsInserted(const KItemRangeList& itemRanges)
         m_anchorItem = 0;
     } else {
         int inc = 0;
-        foreach (const KItemRange& itemRange, itemRanges) {
+        for (const KItemRange& itemRange : itemRanges) {
             if (m_anchorItem < itemRange.index) {
                 break;
             }
@@ -271,7 +258,7 @@ void KItemListSelectionManager::itemsInserted(const KItemRangeList& itemRanges)
 
         for (int index: previous) {
             int inc = 0;
-            foreach (const KItemRange& itemRange, itemRanges) {
+            for (const KItemRange& itemRange : itemRanges) {
                 if (index < itemRange.index) {
                     break;
                 }
@@ -283,7 +270,7 @@ void KItemListSelectionManager::itemsInserted(const KItemRangeList& itemRanges)
 
     const KItemSet selection = selectedItems();
     if (selection != previousSelection) {
-        emit selectionChanged(selection, previousSelection);
+        Q_EMIT selectionChanged(selection, previousSelection);
     }
 }
 
@@ -296,12 +283,12 @@ void KItemListSelectionManager::itemsRemoved(const KItemRangeList& itemRanges)
     // Update the current item
     m_currentItem = indexAfterRangesRemoving(m_currentItem, itemRanges, DiscardRemovedIndex);
     if (m_currentItem != previousCurrent) {
-        emit currentChanged(m_currentItem, previousCurrent);
+        Q_EMIT currentChanged(m_currentItem, previousCurrent);
         if (m_currentItem < 0) {
             // Calling setCurrentItem() would trigger the selectionChanged signal, but we want to
             // emit it only once in this function -> change the current item manually and emit currentChanged
             m_currentItem = indexAfterRangesRemoving(previousCurrent, itemRanges, AdjustRemovedIndex);
-            emit currentChanged(m_currentItem, -1);
+            Q_EMIT currentChanged(m_currentItem, -1);
         }
     }
 
@@ -328,7 +315,7 @@ void KItemListSelectionManager::itemsRemoved(const KItemRangeList& itemRanges)
 
     const KItemSet selection = selectedItems();
     if (selection != previousSelection) {
-        emit selectionChanged(selection, previousSelection);
+        Q_EMIT selectionChanged(selection, previousSelection);
     }
 
     Q_ASSERT(m_currentItem < m_model->count());
@@ -356,7 +343,7 @@ void KItemListSelectionManager::itemsMoved(const KItemRange& itemRange, const QL
         // Calling setCurrentItem would trigger the selectionChanged signal, but we want to
         // emit it only once in this function -> change the current item manually and emit currentChanged
         m_currentItem = newCurrentItem;
-        emit currentChanged(newCurrentItem, previousCurrentItem);
+        Q_EMIT currentChanged(newCurrentItem, previousCurrentItem);
     }
 
     // Start a new anchored selection.
@@ -381,7 +368,7 @@ void KItemListSelectionManager::itemsMoved(const KItemRange& itemRange, const QL
 
     const KItemSet selection = selectedItems();
     if (selection != previousSelection) {
-        emit selectionChanged(selection, previousSelection);
+        Q_EMIT selectionChanged(selection, previousSelection);
     }
 }
 
@@ -389,7 +376,7 @@ int KItemListSelectionManager::indexAfterRangesRemoving(int index, const KItemRa
                                                         const RangesRemovingBehaviour behaviour) const
 {
     int dec = 0;
-    foreach (const KItemRange& itemRange, itemRanges) {
+    for (const KItemRange& itemRange : itemRanges) {
         if (index < itemRange.index) {
             break;
         }
