@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2012 by Peter Penz <peter.penz19@gmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2012 Peter Penz <peter.penz19@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "kstandarditemlistwidget.h"
 
@@ -217,7 +204,7 @@ void KStandardItemListWidgetInformant::calculateCompactLayoutItemSizeHints(QVect
             maximumRequiredWidth = fontMetrics.horizontalAdvance(itemText(index, view));
         } else {
             const QHash<QByteArray, QVariant>& values = view->model()->data(index);
-            foreach (const QByteArray& role, visibleRoles) {
+            for (const QByteArray& role : visibleRoles) {
                 const QString& text = roleText(role, values);
                 const qreal requiredWidth = fontMetrics.horizontalAdvance(text);
                 maximumRequiredWidth = qMax(maximumRequiredWidth, requiredWidth);
@@ -245,6 +232,7 @@ void KStandardItemListWidgetInformant::calculateDetailsLayoutItemSizeHints(QVect
 
 KStandardItemListWidget::KStandardItemListWidget(KItemListWidgetInformant* informant, QGraphicsItem* parent) :
     KItemListWidget(informant, parent),
+    m_textInfo(),
     m_isCut(false),
     m_isHidden(false),
     m_customizedFont(),
@@ -260,7 +248,6 @@ KStandardItemListWidget::KStandardItemListWidget(KItemListWidgetInformant* infor
     m_scaledPixmapSize(),
     m_iconRect(),
     m_hoverPixmap(),
-    m_textInfo(),
     m_textRect(),
     m_sortedVisibleRoles(),
     m_expansionArea(),
@@ -327,7 +314,7 @@ void KStandardItemListWidget::paint(QPainter* painter, const QStyleOptionGraphic
     }
 
     const KItemListStyleOption& itemListStyleOption = styleOption();
-    if (isHovered()) {
+    if (isHovered() && !m_pixmap.isNull()) {
         if (hoverOpacity() < 1.0) {
             /*
              * Linear interpolation between m_pixmap and m_hoverPixmap.
@@ -370,7 +357,7 @@ void KStandardItemListWidget::paint(QPainter* painter, const QStyleOptionGraphic
         } else {
             drawPixmap(painter, m_hoverPixmap);
         }
-    } else {
+    } else if (!m_pixmap.isNull()) {
         drawPixmap(painter, m_pixmap);
     }
 
@@ -671,7 +658,8 @@ void KStandardItemListWidget::dataChanged(const QHash<QByteArray, QVariant>& cur
 
     QSet<QByteArray> dirtyRoles;
     if (roles.isEmpty()) {
-        dirtyRoles = visibleRoles().toSet();
+        const auto visibleRoles = this->visibleRoles();
+        dirtyRoles = QSet<QByteArray>(visibleRoles.constBegin(), visibleRoles.constEnd());
     } else {
         dirtyRoles = roles;
     }
@@ -753,7 +741,7 @@ void KStandardItemListWidget::editedRoleChanged(const QByteArray& current, const
     QGraphicsView* parent = scene()->views()[0];
     if (current.isEmpty() || !parent || current != "text") {
         if (m_roleEditor) {
-            emit roleEditingCanceled(index(), current, data().value(current));
+            Q_EMIT roleEditingCanceled(index(), current, data().value(current));
 
             disconnect(m_roleEditor, &KItemListRoleEditor::roleEditingCanceled,
                        this, &KStandardItemListWidget::slotRoleEditingCanceled);
@@ -878,7 +866,7 @@ void KStandardItemListWidget::slotRoleEditingCanceled(const QByteArray& role,
                                                       const QVariant& value)
 {
     closeRoleEditor();
-    emit roleEditingCanceled(index(), role, value);
+    Q_EMIT roleEditingCanceled(index(), role, value);
     setEditedRole(QByteArray());
 }
 
@@ -886,7 +874,7 @@ void KStandardItemListWidget::slotRoleEditingFinished(const QByteArray& role,
                                                       const QVariant& value)
 {
     closeRoleEditor();
-    emit roleEditingFinished(index(), role, value);
+    Q_EMIT roleEditingFinished(index(), role, value);
     setEditedRole(QByteArray());
 }
 
@@ -974,6 +962,11 @@ void KStandardItemListWidget::updatePixmapCache()
             KPixmapModifier::scale(m_pixmap, QSize(maxIconWidth, maxIconHeight) * qApp->devicePixelRatio());
         }
 
+        if (m_pixmap.isNull()) {
+            m_hoverPixmap = QPixmap();
+            return;
+        }
+
         if (m_isCut) {
             KIconEffect* effect = KIconLoader::global()->iconEffect();
             m_pixmap = effect->apply(m_pixmap, KIconLoader::Desktop, KIconLoader::DisabledState);
@@ -986,6 +979,10 @@ void KStandardItemListWidget::updatePixmapCache()
         if (m_layout == IconsLayout && isSelected()) {
             const QColor color = palette().brush(QPalette::Normal, QPalette::Highlight).color();
             QImage image = m_pixmap.toImage();
+            if (image.isNull()) {
+                m_hoverPixmap = QPixmap();
+                return;
+            }
             KIconEffect::colorize(image, color, 0.8f);
             m_pixmap = QPixmap::fromImage(image);
         }
@@ -1125,7 +1122,7 @@ QString KStandardItemListWidget::elideRightKeepExtension(const QString &text, in
             QString ret = m_customizedFontMetrics.elidedText(text.chopped(extensionLength),
                                                              Qt::ElideRight,
                                                              elidingWidth - extensionWidth);
-            ret.append(text.right(extensionLength));
+            ret.append(text.rightRef(extensionLength));
             return ret;
         }
     }
@@ -1217,7 +1214,7 @@ void KStandardItemListWidget::updateIconsLayoutTextCache()
 
     // Calculate the position for each additional information
     qreal y = nameTextInfo->pos.y() + nameHeight;
-    foreach (const QByteArray& role, m_sortedVisibleRoles) {
+    for (const QByteArray& role : qAsConst(m_sortedVisibleRoles)) {
         if (role == "text") {
             continue;
         }
@@ -1280,7 +1277,7 @@ void KStandardItemListWidget::updateCompactLayoutTextCache()
     const qreal x = option.padding * 3 + scaledIconSize;
     qreal y = qRound((widgetHeight - textLinesHeight) / 2);
     const qreal maxWidth = size().width() - x - option.padding;
-    foreach (const QByteArray& role, m_sortedVisibleRoles) {
+    for (const QByteArray& role : qAsConst(m_sortedVisibleRoles)) {
         const QString text = roleText(role, values);
         TextInfo* textInfo = m_textInfo.value(role);
         textInfo->staticText.setText(text);
@@ -1331,7 +1328,7 @@ void KStandardItemListWidget::updateDetailsLayoutTextCache()
     qreal x = firstColumnInc;
     const qreal y = qMax(qreal(option.padding), (widgetHeight - fontHeight) / 2);
 
-    foreach (const QByteArray& role, m_sortedVisibleRoles) {
+    for (const QByteArray& role : qAsConst(m_sortedVisibleRoles)) {
         QString text = roleText(role, values);
 
         // Elide the text in case it does not fit into the available column-width
@@ -1491,7 +1488,8 @@ QPixmap KStandardItemListWidget::pixmapForIcon(const QString& name, const QStrin
         if (icon.isNull()) {
             icon = QIcon(name);
         }
-        if (icon.isNull()) {
+        if (icon.isNull()
+            || icon.pixmap(size / qApp->devicePixelRatio(), size / qApp->devicePixelRatio(), mode).isNull()) {
             icon = fallbackIcon;
         }
 
@@ -1505,7 +1503,7 @@ QPixmap KStandardItemListWidget::pixmapForIcon(const QString& name, const QStrin
         // It is more efficient to do it here, as KIconLoader::drawOverlays()
         // assumes that an overlay will be drawn and has some additional
         // setup time.
-        foreach (const QString& overlay, overlays) {
+        for (const QString& overlay : overlays) {
             if (!overlay.isEmpty()) {
                 int state = KIconLoader::DefaultState;
 
