@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2009-2010 by Peter Penz <peter.penz19@gmail.com>        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2009-2010 Peter Penz <peter.penz19@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #ifndef INFORMATIONPANELCONTENT_H
 #define INFORMATIONPANELCONTENT_H
@@ -36,6 +23,7 @@ class QDialogButtonBox;
 class QString;
 class QLabel;
 class QScrollArea;
+class QGestureEvent;
 
 namespace KIO {
   class PreviewJob;
@@ -91,6 +79,7 @@ public:
 signals:
     void urlActivated( const QUrl& url );
     void configurationFinished();
+    void contextMenuRequested(const QPoint& pos);
 
 public slots:
     /**
@@ -103,6 +92,8 @@ protected:
     /** @see QObject::eventFilter() */
     bool eventFilter(QObject* obj, QEvent* event) override;
 
+    bool event(QEvent * event) override;
+
 private slots:
     /**
      * Is invoked if no preview is available for the item. In this
@@ -144,6 +135,8 @@ private:
      */
     void refreshPixmapView();
 
+    bool gestureEvent(QGestureEvent* event);
+
 private:
     KFileItem m_item;
 
