@@ -1,21 +1,8 @@
-/***************************************************************************
-*    Copyright (C) 2010 by Peter Penz <peter.penz19@gmail.com>            *
-*                                                                         *
-*    This program is free software; you can redistribute it and/or modify *
-*    it under the terms of the GNU General Public License as published by *
-*    the Free Software Foundation; either version 2 of the License, or    *
-*    (at your option) any later version.                                  *
-*                                                                         *
-*    This program is distributed in the hope that it will be useful,      *
-*    but WITHOUT ANY WARRANTY; without even the implied warranty of       *
-*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
-*    GNU General Public License for more details.                         *
-*                                                                         *
-*    You should have received a copy of the GNU General Public License    *
-*    along with this program; if not, write to the                        *
-*    Free Software Foundation, Inc.,                                      *
-*    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA           *
-* **************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2010 Peter Penz <peter.penz19@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "global.h"
 #include "dolphinsearchbox.h"
@@ -177,7 +164,7 @@ void DolphinSearchBox::setActive(bool active)
         m_active = active;
 
         if (active) {
-            emit activated();
+            Q_EMIT activated();
         }
     }
 }
@@ -215,13 +202,13 @@ void DolphinSearchBox::keyReleaseEvent(QKeyEvent* event)
     QWidget::keyReleaseEvent(event);
     if (event->key() == Qt::Key_Escape) {
         if (m_searchInput->text().isEmpty()) {
-            emit closeRequest();
+            Q_EMIT closeRequest();
         } else {
             m_searchInput->clear();
         }
     }
     else if (event->key() == Qt::Key_Down) {
-        emit focusViewRequest();
+        Q_EMIT focusViewRequest();
     }
 }
 
@@ -254,7 +241,7 @@ void DolphinSearchBox::emitSearchRequest()
     m_startSearchTimer->stop();
     m_startedSearching = true;
     m_saveSearchAction->setEnabled(true);
-    emit searchRequest();
+    Q_EMIT searchRequest();
 }
 
 void DolphinSearchBox::emitCloseRequest()
@@ -262,7 +249,7 @@ void DolphinSearchBox::emitCloseRequest()
     m_startSearchTimer->stop();
     m_startedSearching = false;
     m_saveSearchAction->setEnabled(false);
-    emit closeRequest();
+    Q_EMIT closeRequest();
 }
 
 void DolphinSearchBox::slotConfigurationChanged()
@@ -281,20 +268,20 @@ void DolphinSearchBox::slotSearchTextChanged(const QString& text)
     } else {
         m_startSearchTimer->start();
     }
-    emit searchTextChanged(text);
+    Q_EMIT searchTextChanged(text);
 }
 
 void DolphinSearchBox::slotReturnPressed()
 {
     emitSearchRequest();
-    emit focusViewRequest();
+    Q_EMIT focusViewRequest();
 }
 
 void DolphinSearchBox::slotFacetChanged()
 {
     m_startedSearching = true;
     m_startSearchTimer->stop();
-    emit searchRequest();
+    Q_EMIT searchRequest();
 }
 
 void DolphinSearchBox::slotSearchSaved()
