@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2019 by Ismael Asensio <isma.af@gmail.com>              *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2019 Ismael Asensio <isma.af@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "search/dolphinquery.h"
 
@@ -150,6 +137,15 @@ void DolphinSearchBoxTest::testBalooSearchParsing_data()
     QTest::newRow("allTerms/space")
         << balooQueryUrl(textS + " " + filenameS + " " + rating + " AND " + modified + " AND " + tagS)
         << textS + " " + filenameS << QStringList({modified, rating, tagR}) << true << true;
+
+    // Test tags:/ URL scheme
+    const auto tagUrl   = [](const QString &tag) { return QUrl(QStringLiteral("tags:/%1/").arg(tag)); };
+    const auto tagTerms = [](const QString &tag) { return QStringList{QStringLiteral("tag:%1").arg(tag)}; };
+
+    QTest::newRow("tagsUrl")       << tagUrl("tagA")             << "" << tagTerms("tagA")             << false << false;
+    QTest::newRow("tagsUrl/space") << tagUrl("tagB with spaces") << "" << tagTerms("tagB with spaces") << false << false;
+    QTest::newRow("tagsUrl/hash")  << tagUrl("tagC#hash")        << "" << tagTerms("tagC#hash")        << false << false;
+    QTest::newRow("tagsUrl/slash") << tagUrl("tagD/with/slash")  << "" << tagTerms("tagD/with/slash")  << false << false;
 }
 
 /**
